@@ -11,6 +11,7 @@ pub use safe_network::types::register::{Entry, EntryHash};
 
 use crate::{Error, Result, Safe};
 use log::debug;
+use safe_network::types::{DataAddress, RegisterAddress};
 use safe_network::url::{ContentType, Scope, Url, XorUrl};
 use std::collections::BTreeSet;
 use xor_name::XorName;
@@ -42,7 +43,7 @@ impl Safe {
     /// Read value from a Register on the network
     pub async fn register_read(&self, url: &str) -> Result<BTreeSet<(EntryHash, Entry)>> {
         debug!("Getting Public Register data from: {:?}", url);
-        let (safeurl, _) = self.parse_and_resolve_url(url).await?;
+        let safeurl = self.parse_and_resolve_url(url).await?;
 
         self.fetch_register_entries(&safeurl).await
     }
@@ -50,7 +51,7 @@ impl Safe {
     /// Read value from a Register on the network by its hash
     pub async fn register_read_entry(&self, url: &str, hash: EntryHash) -> Result<Entry> {
         debug!("Getting Public Register data from: {:?}", url);
-        let (safeurl, _) = self.parse_and_resolve_url(url).await?;
+        let safeurl = self.parse_and_resolve_url(url).await?;
 
         self.fetch_register_entry(&safeurl, hash).await
     }
@@ -60,51 +61,45 @@ impl Safe {
     /// e.g. safe://mysafeurl?v=ce56a3504c8f27bfeb13bdf9051c2e91409230ea
     pub(crate) async fn fetch_register_entries(
         &self,
-        safeurl: &Url,
+        url: &Url,
     ) -> Result<BTreeSet<(EntryHash, Entry)>> {
-        let result = match safeurl.content_version() {
+        let result = match url.content_version() {
             Some(v) => {
                 debug!("Take entry with version hash");
                 let hash = v.entry_hash();
-                self.fetch_register_entry(safeurl, hash)
+                self.fetch_register_entry(url, hash)
                     .await
                     .map(|entry| vec![(hash, entry)].into_iter().collect())
             }
             None => {
                 debug!("No version so take latest entry");
-                let address = safeurl.register_address()?;
+                let address = self.get_register_address(url)?;
                 self.safe_client.read_register(address).await
             }
         };
 
         match result {
             Ok(data) => {
-                debug!("Register retrieved from {}...", safeurl);
+                debug!("Register retrieved from {}...", url);
                 Ok(data)
             }
             Err(Error::EmptyContent(_)) => Err(Error::EmptyContent(format!(
                 "Register found at \"{}\" was empty",
-                safeurl
+                url
             ))),
             Err(Error::ContentNotFound(_)) => Err(Error::ContentNotFound(format!(
                 "No Register found at \"{}\"",
-                safeurl
+                url
             ))),
             other_err => other_err,
         }
     }
 
     /// Fetch a Register from a Url without performing any type of URL resolution
-    pub(crate) async fn fetch_register_entry(
-        &self,
-        safeurl: &Url,
-        hash: EntryHash,
-    ) -> Result<Entry> {
+    pub(crate) async fn fetch_register_entry(&self, url: &Url, hash: EntryHash) -> Result<Entry> {
         // TODO: allow to specify the hash with the Url as well: safeurl.content_hash(),
         // e.g. safe://mysafeurl#ce56a3504c8f27bfeb13bdf9051c2e91409230ea
-        let address = safeurl.register_address()?;
-
-        // We fetch a specific entry with provided hash
+        let address = self.get_register_address(url)?;
         self.safe_client.get_register_entry(address, hash).await
     }
 
@@ -127,19 +122,31 @@ impl Safe {
         };
         */
 
-        let (safeurl, _) = self.parse_and_resolve_url(url).await?;
-        let address = safeurl.register_address()?;
-
-        // write the entry to the Register
+        let reg_url = self.parse_and_resolve_url(url).await?;
+        let address = self.get_register_address(&reg_url)?;
         self.safe_client
             .write_to_register(address, entry, parents)
             .await
     }
+
+    pub(crate) fn get_register_address(&self, url: &Url) -> Result<RegisterAddress> {
+        let address = match url.address() {
+            DataAddress::Register(reg_address) => reg_address,
+            other => {
+                return Err(Error::ContentError(format!(
+                    "The url {} has an {:?} address.\
+                    To fetch register entries, this url must refer to a register.",
+                    url, other
+                )))
+            }
+        };
+        Ok(address)
+    }
 }
 
 #[cfg(test)]
 mod tests {
-    use crate::{app::test_helpers::new_safe_instance, retry_loop, Url};
+    use crate::{app::test_helpers::new_safe_instance, Url};
     use anyhow::Result;
 
     #[tokio::test]
@@ -149,8 +156,8 @@ mod tests {
         let xorurl = safe.register_create(None, 25_000, false).await?;
         let xorurl_priv = safe.register_create(None, 25_000, true).await?;
 
-        let received_data = retry_loop!(safe.register_read(&xorurl));
-        let received_data_priv = retry_loop!(safe.register_read(&xorurl_priv));
+        let received_data = safe.register_read(&xorurl).await?;
+        let received_data_priv = safe.register_read(&xorurl_priv).await?;
 
         assert!(received_data.is_empty());
         assert!(received_data_priv.is_empty());
@@ -163,8 +170,8 @@ mod tests {
             .write_to_register(&xorurl_priv, initial_data.clone(), Default::default())
             .await?;
 
-        let received_entry = retry_loop!(safe.register_read_entry(&xorurl, hash));
-        let received_entry_priv = retry_loop!(safe.register_read_entry(&xorurl_priv, hash_priv));
+        let received_entry = safe.register_read_entry(&xorurl, hash).await?;
+        let received_entry_priv = safe.register_read_entry(&xorurl_priv, hash_priv).await?;
 
         assert_eq!(received_entry, initial_data.clone());
         assert_eq!(received_entry_priv, initial_data);
