@@ -86,6 +86,9 @@ pub enum Error {
     /// NotEnoughBalance
     #[error("NotEnoughBalance: {0}")]
     NotEnoughBalance(String),
+    /// NrsNameAlreadyExists
+    #[error("NrsNameAlreadyExists: {0}")]
+    NrsNameAlreadyExists(String),
     /// Serialisation
     #[error("Serialisation: {0}")]
     Serialisation(String),
@@ -95,10 +98,13 @@ pub enum Error {
     /// UrlError
     #[error("UrlError: {0}")]
     UrlError(#[from] UrlError),
+    /// UnversionedContentError
+    #[error("UnversionedContentError: {0}")]
+    UnversionedContentError(String),
     /// NotImplementedError
     #[error("NotImplementedError: {0}")]
     NotImplementedError(String),
-    /// MultimapFork
-    #[error("MultimapFork: {0}")]
-    MultimapFork(String),
+    /// RegisterFork
+    #[error("RegisterFork: {0}")]
+    RegisterFork(String),
 }
